# hsgconv
Coordinate conversion methods between [England's Highways Standards and British National Grid (OSBG36 or EPSG:27700)][1] in pure Python.

![][hestandardgrids]

## Install
The module can be installed through pip by running ```pip install hsgconv```. The example shows the recommended way to proceed and shows  cumulative errors.

___

**Note:** Tested on Python 2.7 and IronPython 2.7 - should work on 3.x too.

[1]: http://www.standardsforhighways.co.uk/ha/standards/ians/pdfs/ian99.pdf "Standards for Highways"
[hestandardgrids]: https://github.com/ccampanile/hsgconv/raw/master/examples/localgrids.PNG
